@@ -3,7 +3,7 @@
 void H1(int n, double *x) {
   int i;
   for (i=0;i<n;i++) {
-    x[i] = sqrt(3.0) * x[i];
+    x[i] = std::sqrt(3.0) * x[i];
   }
   return;
 }
