@@ -75,7 +75,7 @@ Fin-Commentaires */
 void H5(int n, double *x) {
   int i;
   for (i = 0; i < n; i++) {
-    x[i] = sqrt(11.0) * (63.0 * pow(x[i], 5.0) - 70.0 * pow(x[i], 3.0) + 15.0 * x[i]) / 8.0;
+    x[i] = std::sqrt(11.0) * (63.0 * std::pow(x[i], 5.0) - 70.0 * std::pow(x[i], 3.0) + 15.0 * x[i]) / 8.0;
   }
   return;
 }
